gsh/command/history
The history module provides functionality for reviewing previous commands.
When a user wants to see their session’s execution history, this module formats and prints the chronologically ordered list of inputs.
The history module provides functionality for reviewing previous commands.
When a user wants to see their session’s execution history, this module formats and prints the chronologically ordered list of inputs.