gsh/command/help
The help module provides the built-in command reference for the interactive shell.
It handles rendering the help menu when the user requests assistance, providing a quick cheat sheet for REPL-specific utilities, inspection tools, and hot-reloading commands.