gsh/command/help
The help module provides the built-in command reference for the interactive shell.
It handles rendering the help menu when the user types the h() command,
giving them a quick cheat sheet for REPL-specific utilities.
The help module provides the built-in command reference for the interactive shell.
It handles rendering the help menu when the user types the h() command,
giving them a quick cheat sheet for REPL-specific utilities.