gsh/command/version
The version module handles the built-in version inspection command.
When a user types v(), this module queries the Erlang application
controller to dynamically fetch the current running version of GSH and prints it.
The version module handles the built-in version inspection command.
When a user types v(), this module queries the Erlang application
controller to dynamically fetch the current running version of GSH and prints it.